"""This file was generated by xsdata, v26.1, on 2026-02-18 00:41:07

Generator: DataclassGenerator
See: https://xsdata.readthedocs.io/
"""

from __future__ import annotations

from dataclasses import dataclass

from ccsds_ndm.models.ndmxml4.ndmxml_4_0_0_acm_2_0 import AcmType
from ccsds_ndm.models.ndmxml4.ndmxml_4_0_0_aem_2_0 import AemType
from ccsds_ndm.models.ndmxml4.ndmxml_4_0_0_apm_2_0 import ApmType
from ccsds_ndm.models.ndmxml4.ndmxml_4_0_0_cdm_1_0 import CdmType
from ccsds_ndm.models.ndmxml4.ndmxml_4_0_0_ndm_4_0 import NdmType
from ccsds_ndm.models.ndmxml4.ndmxml_4_0_0_ocm_3_0 import OcmType
from ccsds_ndm.models.ndmxml4.ndmxml_4_0_0_oem_3_0 import OemType
from ccsds_ndm.models.ndmxml4.ndmxml_4_0_0_omm_3_0 import OmmType
from ccsds_ndm.models.ndmxml4.ndmxml_4_0_0_opm_3_0 import OpmType
from ccsds_ndm.models.ndmxml4.ndmxml_4_0_0_rdm_1_0 import RdmType
from ccsds_ndm.models.ndmxml4.ndmxml_4_0_0_tdm_2_0 import TdmType


@dataclass(kw_only=True)
class Acm(AcmType):
    class Meta:
        name = "acm"


@dataclass(kw_only=True)
class Aem(AemType):
    class Meta:
        name = "aem"


@dataclass(kw_only=True)
class Apm(ApmType):
    class Meta:
        name = "apm"


@dataclass(kw_only=True)
class Cdm(CdmType):
    class Meta:
        name = "cdm"


@dataclass(kw_only=True)
class Ndm(NdmType):
    class Meta:
        name = "ndm"


@dataclass(kw_only=True)
class Ocm(OcmType):
    class Meta:
        name = "ocm"


@dataclass(kw_only=True)
class Oem(OemType):
    class Meta:
        name = "oem"


@dataclass(kw_only=True)
class Omm(OmmType):
    class Meta:
        name = "omm"


@dataclass(kw_only=True)
class Opm(OpmType):
    class Meta:
        name = "opm"


@dataclass(kw_only=True)
class Rdm(RdmType):
    class Meta:
        name = "rdm"


@dataclass(kw_only=True)
class Tdm(TdmType):
    class Meta:
        name = "tdm"
