"""This file was generated by xsdata, v26.1, on 2026-02-18 00:40:52

Generator: DataclassGenerator
See: https://xsdata.readthedocs.io/
"""

from ccsds_ndm.models.ndmxml1.ndmxml_1_0_aem_1_0 import (
    AemBody,
    AemData,
    AemMetadata,
    AemRateFrameType,
    AemSegment,
    AemType,
    AttitudeStateType,
    AttitudeTypeType,
    EulerAngleRateType,
    EulerAngleType,
    QuaternionDerivativeType,
    QuaternionEphemerisType,
    QuaternionEulerRateType,
    QuaternionTypeType,
    SpinNutationType,
    SpinType,
)
from ccsds_ndm.models.ndmxml1.ndmxml_1_0_apm_1_0 import (
    ApmBody,
    ApmData,
    ApmMetadata,
    ApmRateFrameType,
    ApmSegment,
    ApmType,
    AttManeuverParametersType,
    AttSpacecraftParametersType,
    EulerElementsSpinType,
    EulerElementsThreeType,
    MomentType,
    MomentUnits,
    QuaternionStateType,
    TorqueType,
    TorqueUnits,
)
from ccsds_ndm.models.ndmxml1.ndmxml_1_0_cdm_1_0 import (
    AdditionalParametersType,
    CdmBody,
    CdmCovarianceType,
    CdmData,
    CdmHeader,
    CdmMetadata,
    CdmPositionType,
    CdmSegment,
    CdmStateVectorType,
    CdmType,
    CdmVelocityType,
    CovarianceMethodType,
    DvType,
    DvUnits,
    M2KgType,
    M2KgUnits,
    M2S2Type,
    M2S2Units,
    M2S3Type,
    M2S3Units,
    M2S4Type,
    M2S4Units,
    M2SType,
    M2SUnits,
    M2Type,
    M2Units,
    M3Kgs2Type,
    M3Kgs2Units,
    M3KgsType,
    M3KgsUnits,
    M3KgType,
    M3KgUnits,
    M4Kg2Type,
    M4Kg2Units,
    ManeuverableType,
    ObjectType,
    ReferenceFrameType,
    RelativeMetadataData,
    RelativeStateVectorType,
    ScreenVolumeFrameType,
    ScreenVolumeShapeType,
    WkgType,
    WkgUnits,
)
from ccsds_ndm.models.ndmxml1.ndmxml_1_0_master import (
    Aem,
    Apm,
    Cdm,
    Ndm,
    Oem,
    Omm,
    Opm,
    Rdm,
    Tdm,
)
from ccsds_ndm.models.ndmxml1.ndmxml_1_0_navwg_common import (
    AccType,
    AccUnits,
    AltType,
    AngleKeywordType,
    AngleRateKeywordType,
    AngleRateType,
    AngleRateUnits,
    AngleType,
    AngleUnits,
    AreaType,
    AreaUnits,
    AtmosphericReentryParametersType,
    BallisticCoeffType,
    BallisticCoeffUnitsType,
    ControlledType,
    DayIntervalType,
    DayIntervalUnits,
    DeltamassType,
    DisintegrationType,
    DistanceType,
    DurationType,
    FrequencyType,
    FrequencyUnits,
    GmType,
    GmUnits,
    GroundImpactParametersType,
    ImpactUncertaintyType,
    InclinationType,
    Km2S2Type,
    Km2S2Units,
    Km2SType,
    Km2SUnits,
    Km2Type,
    Km2Units,
    LatLonUnits,
    LatType,
    LengthType,
    LengthUnits,
    LonType,
    MassType,
    MassUnits,
    Ms2Type,
    Ms2Units,
    NdmHeader,
    ObjectDescriptionType,
    OdParametersType,
    OemCovarianceMatrixAbstractType,
    OemCovarianceMatrixType,
    OpmCovarianceMatrixAbstractType,
    OpmCovarianceMatrixType,
    PercentageType,
    PercentageUnits,
    PositionCovarianceType,
    PositionCovarianceUnits,
    PositionType,
    PositionUnits,
    PositionVelocityCovarianceType,
    PositionVelocityCovarianceUnits,
    QuaternionDotType,
    QuaternionDotUnits,
    QuaternionRateType,
    QuaternionType,
    RdmPositionType,
    RdmSpacecraftParametersType,
    RdmVelocityType,
    ReentryUncertaintyMethodType,
    RotationAngleComponentType,
    RotationAngleComponentTypeold,
    RotationAngleType,
    RotationRateComponentType,
    RotationRateComponentTypeOld,
    RotationRateType,
    RotDirectionType,
    RotseqType,
    SpacecraftParametersType,
    StateVectorAccType,
    StateVectorType,
    TimeSystemType,
    TimeUnits,
    UserDefinedParameterType,
    UserDefinedType,
    VelocityCovarianceType,
    VelocityCovarianceUnits,
    VelocityType,
    VelocityUnits,
    YesNoType,
)
from ccsds_ndm.models.ndmxml1.ndmxml_1_0_ndm_1_0 import NdmType
from ccsds_ndm.models.ndmxml1.ndmxml_1_0_oem_2_0 import (
    OemBody,
    OemData,
    OemMetadata,
    OemSegment,
    OemType,
)
from ccsds_ndm.models.ndmxml1.ndmxml_1_0_omm_2_0 import (
    BStarType,
    BStarUnits,
    DdRevType,
    DdRevUnits,
    DRevType,
    DRevUnits,
    MeanElementsType,
    OmmBody,
    OmmData,
    OmmMetadata,
    OmmSegment,
    OmmType,
    RevType,
    RevUnits,
    TleParametersType,
)
from ccsds_ndm.models.ndmxml1.ndmxml_1_0_opm_2_0 import (
    KeplerianElementsType,
    ManeuverParametersType,
    OpmBody,
    OpmData,
    OpmMetadata,
    OpmSegment,
    OpmType,
)
from ccsds_ndm.models.ndmxml1.ndmxml_1_0_rdm_1_0 import (
    RdmBody,
    RdmData,
    RdmHeader,
    RdmMetadata,
    RdmSegment,
    RdmType,
)
from ccsds_ndm.models.ndmxml1.ndmxml_1_0_tdm_1_0 import (
    AngleTypeType,
    DataQualityType,
    IntegrationRefType,
    ModeType,
    RangemodeType,
    RangeUnitsType,
    RefFrameType,
    TdmBody,
    TdmData,
    TdmMetadata,
    TdmSegment,
    TdmType,
    TimetagRefType,
    TrackingDataObservationType,
)

__all__ = [
    "AemBody",
    "AemData",
    "AemMetadata",
    "AemRateFrameType",
    "AemSegment",
    "AemType",
    "AttitudeStateType",
    "AttitudeTypeType",
    "EulerAngleRateType",
    "EulerAngleType",
    "QuaternionDerivativeType",
    "QuaternionEphemerisType",
    "QuaternionEulerRateType",
    "QuaternionTypeType",
    "SpinNutationType",
    "SpinType",
    "ApmBody",
    "ApmData",
    "ApmMetadata",
    "ApmRateFrameType",
    "ApmSegment",
    "ApmType",
    "AttManeuverParametersType",
    "AttSpacecraftParametersType",
    "EulerElementsSpinType",
    "EulerElementsThreeType",
    "MomentType",
    "MomentUnits",
    "QuaternionStateType",
    "TorqueType",
    "TorqueUnits",
    "AdditionalParametersType",
    "CdmBody",
    "CdmCovarianceType",
    "CdmData",
    "CdmHeader",
    "CdmMetadata",
    "CdmPositionType",
    "CdmSegment",
    "CdmStateVectorType",
    "CdmType",
    "CdmVelocityType",
    "CovarianceMethodType",
    "DvType",
    "DvUnits",
    "M2Type",
    "M2Units",
    "M2KgType",
    "M2KgUnits",
    "M2S2Type",
    "M2S2Units",
    "M2S3Type",
    "M2S3Units",
    "M2S4Type",
    "M2S4Units",
    "M2SType",
    "M2SUnits",
    "M3KgType",
    "M3KgUnits",
    "M3Kgs2Type",
    "M3Kgs2Units",
    "M3KgsType",
    "M3KgsUnits",
    "M4Kg2Type",
    "M4Kg2Units",
    "ManeuverableType",
    "ObjectType",
    "ReferenceFrameType",
    "RelativeMetadataData",
    "RelativeStateVectorType",
    "ScreenVolumeFrameType",
    "ScreenVolumeShapeType",
    "WkgType",
    "WkgUnits",
    "Aem",
    "Apm",
    "Cdm",
    "Ndm",
    "Oem",
    "Omm",
    "Opm",
    "Rdm",
    "Tdm",
    "AccType",
    "AccUnits",
    "AltType",
    "AngleKeywordType",
    "AngleRateKeywordType",
    "AngleRateType",
    "AngleRateUnits",
    "AngleType",
    "AngleUnits",
    "AreaType",
    "AreaUnits",
    "AtmosphericReentryParametersType",
    "BallisticCoeffType",
    "BallisticCoeffUnitsType",
    "ControlledType",
    "DayIntervalType",
    "DayIntervalUnits",
    "DeltamassType",
    "DisintegrationType",
    "DistanceType",
    "DurationType",
    "FrequencyType",
    "FrequencyUnits",
    "GmType",
    "GmUnits",
    "GroundImpactParametersType",
    "ImpactUncertaintyType",
    "InclinationType",
    "Km2Type",
    "Km2Units",
    "Km2S2Type",
    "Km2S2Units",
    "Km2SType",
    "Km2SUnits",
    "LatLonUnits",
    "LatType",
    "LengthType",
    "LengthUnits",
    "LonType",
    "MassType",
    "MassUnits",
    "Ms2Type",
    "Ms2Units",
    "NdmHeader",
    "ObjectDescriptionType",
    "OdParametersType",
    "OemCovarianceMatrixAbstractType",
    "OemCovarianceMatrixType",
    "OpmCovarianceMatrixAbstractType",
    "OpmCovarianceMatrixType",
    "PercentageType",
    "PercentageUnits",
    "PositionCovarianceType",
    "PositionCovarianceUnits",
    "PositionType",
    "PositionUnits",
    "PositionVelocityCovarianceType",
    "PositionVelocityCovarianceUnits",
    "QuaternionDotType",
    "QuaternionDotUnits",
    "QuaternionRateType",
    "QuaternionType",
    "RdmPositionType",
    "RdmSpacecraftParametersType",
    "RdmVelocityType",
    "ReentryUncertaintyMethodType",
    "RotDirectionType",
    "RotationAngleComponentType",
    "RotationAngleComponentTypeold",
    "RotationAngleType",
    "RotationRateComponentType",
    "RotationRateComponentTypeOld",
    "RotationRateType",
    "RotseqType",
    "SpacecraftParametersType",
    "StateVectorAccType",
    "StateVectorType",
    "TimeSystemType",
    "TimeUnits",
    "UserDefinedParameterType",
    "UserDefinedType",
    "VelocityCovarianceType",
    "VelocityCovarianceUnits",
    "VelocityType",
    "VelocityUnits",
    "YesNoType",
    "NdmType",
    "OemBody",
    "OemData",
    "OemMetadata",
    "OemSegment",
    "OemType",
    "BStarType",
    "BStarUnits",
    "DRevType",
    "DRevUnits",
    "DdRevType",
    "DdRevUnits",
    "MeanElementsType",
    "OmmBody",
    "OmmData",
    "OmmMetadata",
    "OmmSegment",
    "OmmType",
    "RevType",
    "RevUnits",
    "TleParametersType",
    "KeplerianElementsType",
    "ManeuverParametersType",
    "OpmBody",
    "OpmData",
    "OpmMetadata",
    "OpmSegment",
    "OpmType",
    "RdmBody",
    "RdmData",
    "RdmHeader",
    "RdmMetadata",
    "RdmSegment",
    "RdmType",
    "AngleTypeType",
    "DataQualityType",
    "IntegrationRefType",
    "ModeType",
    "RangeUnitsType",
    "RangemodeType",
    "RefFrameType",
    "TdmBody",
    "TdmData",
    "TdmMetadata",
    "TdmSegment",
    "TdmType",
    "TimetagRefType",
    "TrackingDataObservationType",
]
